@@ -2,27 +2,29 @@ from __future__ import absolute_import, unicode_literals
 
 import os
 import sentry_sdk
+import logging
 
 # set the default Django settings module for the 'celery' program.
 from django.conf import settings
 
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'crm.settings')
 
-from dotenv import load_dotenv, find_dotenv
-from pathlib import Path
-dotenv_filename = '.crm'
-dotenv_path = find_dotenv(
-    filename=dotenv_filename,
-    raise_error_if_not_found=True,
-    usecwd=False
-)
-print('Load dotenv configuration from %s' % dotenv_path)
-load_dotenv(dotenv_path=dotenv_path, override=True)
+try:
+    from dotenv import load_dotenv, find_dotenv
+    from pathlib import Path
+    dotenv_path = find_dotenv(raise_error_if_not_found=True)
+    dotenv_result = load_dotenv(dotenv_path=dotenv_path)
+    print('dotenv[celery] configuration %s from "%s"' % ('loaded' if dotenv_result else 'not loaded', dotenv_path))
+except BaseException as e:
+    logging.exception(e)
 
 os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 
-import configurations
-configurations.setup()
+try:
+    import configurations
+    configurations.setup()
+except BaseException as e:
+    logging.exception(e)
 
 from celery import Celery
 app = Celery('crm')
