@@ -593,6 +593,7 @@ class Production(Staging):
     Production CRM configuration, secure and rmd.
     """
     DEBUG = False
+    CELERY_TASK_ALWAYS_EAGER = False
 
     def STATIC_ROOT(self):
         return values.PathValue(
@@ -616,7 +617,7 @@ class Production(Staging):
         logging.debug("done setting up! \o/")
 
         sentry_sdk.init(
-            dsn=cls.SENTRY_DSN_URL.value,
+            dsn=cls.SENTRY_DSN_URL,
             integrations=[
                 DjangoIntegration(),
                 CeleryIntegration(),
