@@ -13,14 +13,9 @@ try:
     from dotenv import load_dotenv, find_dotenv
     from pathlib import Path
 
-    dotenv_filename = '.crm'
-    dotenv_path = find_dotenv(
-        filename=dotenv_filename,
-        raise_error_if_not_found=True,
-        usecwd=False
-    )
-    print('Load dotenv configuration from %s' % dotenv_path)
-    load_dotenv(dotenv_path=dotenv_path, override=True)
+    dotenv_path = find_dotenv(raise_error_if_not_found=True)
+    print('dotenv[wsgi] configuration %s from "%s"' % ('loaded' if dotenv_result else 'not loaded', dotenv_path))
+    load_dotenv(dotenv_path=dotenv_path)
 
     os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
 except BaseException as e:
