@@ -4,29 +4,23 @@ import os
 import sys
 
 if __name__ == "__main__":
+
     os.environ.setdefault("DJANGO_SETTINGS_MODULE", "crm.settings")
-    # os.environ['DJANGO_SETTINGS_MODULE'] = "crm.settings"
-    os.environ.setdefault("DJANGO_CONFIGURATION", 'Development')
 
     try:
         from dotenv import load_dotenv, find_dotenv
         from pathlib import Path
 
-        dotenv_filename = '.crm'
-        dotenv_path = find_dotenv(
-            filename=dotenv_filename,
-            raise_error_if_not_found=True,
-            usecwd=False
-        )
-        print('Load dotenv configuration from %s' % dotenv_path)
-        load_dotenv(dotenv_path=dotenv_path, override=True)
-
-        os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
+        dotenv_path = find_dotenv(raise_error_if_not_found=True)
+        dotenv_result = load_dotenv(dotenv_path=dotenv_path)
+        print('dotenv[manage] configuration %s from "%s"' % ('loaded' if dotenv_result else 'not loaded', dotenv_path))
     except BaseException as e:
         logging.error('Dotenv file could not loaded')
         # logging.exception(e)
         # traceback.print_exc()
 
+    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION').capitalize())
+
     try:
         from configurations.management import execute_from_command_line
     except ImportError:
@@ -35,7 +29,6 @@ if __name__ == "__main__":
         # exceptions on Python 2.
         try:
             pass
-
         except ImportError:
             raise ImportError(
                 "Couldn't import Django. Are you sure it's installed and "
@@ -43,4 +36,5 @@ if __name__ == "__main__":
                 "forget to activate a virtual environment?"
             )
         raise
+
     execute_from_command_line(sys.argv)
